Patch #411138: Rename config.h to pyconfig.h.  Closes bug #231774.
diff --git a/Lib/distutils/sysconfig.py b/Lib/distutils/sysconfig.py
index 16e8023..529d0e6 100644
--- a/Lib/distutils/sysconfig.py
+++ b/Lib/distutils/sysconfig.py
@@ -43,7 +43,7 @@
     If 'plat_specific' is false (the default), this is the path to the
     non-platform-specific header files, i.e. Python.h and so on;
     otherwise, this is the path to platform-specific header files
-    (namely config.h).
+    (namely pyconfig.h).
 
     If 'prefix' is supplied, use it instead of sys.prefix or
     sys.exec_prefix -- i.e., ignore 'plat_specific'.
@@ -137,10 +137,10 @@
 
 
 def get_config_h_filename():
     """Return full pathname of installed config.h file."""
     if python_build: inc_dir = '.'
     else:            inc_dir = get_python_inc(plat_specific=1)
-    return os.path.join(inc_dir, "config.h")
+    return os.path.join(inc_dir, "pyconfig.h")
 
 
 def get_makefile_filename():
@@ -137,10 +137,10 @@
 
 def get_config_h_filename():
-    """Return full pathname of installed config.h file."""
+    """Return full pathname of installed pyconfig.h file."""
     if python_build: inc_dir = '.'
     else:            inc_dir = get_python_inc(plat_specific=1)